<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.0">
<context>
    <name>AddProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="27"/>
        <source>Please enter a profile name.</source>
        <translation>Anna profiilille nimi.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="28"/>
        <source>A profile with this name already exists.</source>
        <translation>Samanniminen profiili on jo olemassa.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="24"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="25"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
</context>
<context>
    <name>AddRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="80"/>
        <source>Repository Path:</source>
        <translation>Tietovaraston polku:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="83"/>
        <source>Choose Location of Borg Repository</source>
        <translation>Valitse Borg-tietovaraston sijainti</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="112"/>
        <source>Repository URL:</source>
        <translation>Tietovaraston osoite:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="138"/>
        <source>Unable to add your repository.</source>
        <translation>Tietovaraston lisääminen ei onnistunut.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="165"/>
        <source>Please enter a valid repo URL or select a local path.</source>
        <translation>Anna kelvollinen tietovaraston osoite tai valitse paikallinen polku.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="169"/>
        <source>This repo has already been added.</source>
        <translation>Tämä tietovarasto on jo lisätty.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="105"/>
        <source>Show my passwords</source>
        <translation>Näytä salasanat</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="90"/>
        <source>Autofilled password from password manager.</source>
        <translation>Salasana täytetty automaattisesti salasanahallinnan sovelluksesta.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="102"/>
        <source>Hide my passwords</source>
        <translation>Piilota salasanat</translation>
    </message>
</context>
<context>
    <name>AddRepository</name>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="60"/>
        <source>Initialize New Backup Repository</source>
        <translation>Alusta uusi tietovarasto varmuuskopiolle</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="67"/>
        <source>Repository URL:</source>
        <translation>Tietovaraston osoite:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="82"/>
        <source>csvis8xq@csvis8xq.repo.borgbase.com:repo</source>
        <translation>csvis8xq@csvis8xq.repo.borgbase.com:repo</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="89"/>
        <source>Choose a local path as repository.</source>
        <translation>Valitse paikallinen polku tietovarastoksi.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="103"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="201"/>
        <source>Encryption:</source>
        <translation>Salaus:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="179"/>
        <source>SSH Key:</source>
        <translation>SSH-avain:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="193"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>Valitse SSH-avain automaattisesti (oletus)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="247"/>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="254"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="33"/>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="158"/>
        <source>Advanced</source>
        <translation>Lisäasetukset</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="218"/>
        <source>Extra Borg Arguments:</source>
        <translation>Borgin lisäargumentit:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="116"/>
        <source>Borg passphrase:</source>
        <translation>Borgin tunnuslause:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="143"/>
        <source>Confirm passphrase:</source>
        <translation>Vahvista tunnuslause:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="150"/>
        <source>TextLabel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ArchiveTab</name>
    <message>
        <location filename="../../views/archive_tab.py" line="144"/>
        <source>Archives for %s</source>
        <translation>Arkistot tietovarastolle %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="177"/>
        <source>Archives</source>
        <translation>Arkistot</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="194"/>
        <source>Preview: %s</source>
        <translation>Esikatselu: %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="198"/>
        <source>Error in archive name template.</source>
        <translation>Virhe arkistonimen kaavassa.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="242"/>
        <source>Pruning finished.</source>
        <translation>Karsiminen valmistui.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="261"/>
        <source>Refreshed archives.</source>
        <translation>Arkistot päivitetty.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="315"/>
        <source>Choose Mount Point</source>
        <translation>Valitse liitospiste</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="321"/>
        <source>Mounted successfully.</source>
        <translation>Liitetty onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="348"/>
        <source>Mount point not active.</source>
        <translation>Liitospiste ei ole aktiivinen.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="355"/>
        <source>Un-mounted successfully.</source>
        <translation>Liitos irrotettu onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="393"/>
        <source>Select an archive to restore first.</source>
        <translation>Valitse ensin palautettava arkisto.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="413"/>
        <source>Choose Extraction Point</source>
        <translation>Valitse purkupiste</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="478"/>
        <source>Archive deleted.</source>
        <translation>Arkisto poistettu.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="463"/>
        <source>Confirm deletion</source>
        <translation>Vahvista poistaminen</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="563"/>
        <source>No archive selected</source>
        <translation>Arkistoa ei valittu</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="463"/>
        <source>Are you sure you want to delete the archive?</source>
        <translation>Haluatko varmasti poistaa arkiston?</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="449"/>
        <source>Yes</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="450"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="98"/>
        <source>Action cancelled.</source>
        <translation>Toimenpide peruttu.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="361"/>
        <source>Unmounting failed. Make sure no programs are using {}</source>
        <translation>Käytöstä poisto epäonnistui. Varmista, että mikään ohjelma ei käytä kohdetta {}</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="117"/>
        <source>Select an archive first.</source>
        <translation>Valitse ensin arkisto.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="537"/>
        <source>Change name</source>
        <translation>Vaihda nimi</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="537"/>
        <source>New archive name:</source>
        <translation>Uusi arkiston nimi:</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="547"/>
        <source>Archive name cannot be blank.</source>
        <translation>Arkiston nimi ei voi olla tyhjä.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="552"/>
        <source>An archive with this name already exists.</source>
        <translation>Arkisto tällä nimellä on jo olemassa.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="567"/>
        <source>Archive renamed.</source>
        <translation>Arkisto nimetty uudelleen.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="278"/>
        <source>Refreshed archive.</source>
        <translation>Arkisto päivitetty.</translation>
    </message>
</context>
<context>
    <name>BorgBreakJob</name>
    <message>
        <location filename="../../borg/break_lock.py" line="8"/>
        <source>Breaking repository lock...</source>
        <translation>Murretaan tietovaraston lukko...</translation>
    </message>
    <message>
        <location filename="../../borg/break_lock.py" line="12"/>
        <source>Repository lock broken. Please redo your last action.</source>
        <translation>Tietovaraston lukitus murrettu. Tee uudelleen viimeisin toimenpide.</translation>
    </message>
</context>
<context>
    <name>BorgCheckJob</name>
    <message>
        <location filename="../../borg/check.py" line="8"/>
        <source>Starting consistency check...</source>
        <translation>Käynnistetään yhdenmukaisuuden tarkistus...</translation>
    </message>
    <message>
        <location filename="../../borg/check.py" line="17"/>
        <source>Check completed.</source>
        <translation>Tarkistus valmistui.</translation>
    </message>
    <message>
        <location filename="../../borg/check.py" line="14"/>
        <source>Repo check failed. See logs for details.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgCreateJob</name>
    <message>
        <location filename="../../borg/create.py" line="36"/>
        <source>Backup finished with warnings. See logs for details.</source>
        <translation>Varmuuskopiointi valmistui varoituksin. Katso lokista lisätietoja.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="38"/>
        <source>Backup finished.</source>
        <translation>Varmuuskopiointi valmistui.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="45"/>
        <source>Backup started.</source>
        <translation>Varmuuskopiointi käynnistetty.</translation>
    </message>
</context>
<context>
    <name>BorgDeleteJob</name>
    <message>
        <location filename="../../borg/delete.py" line="8"/>
        <source>Deleting archive...</source>
        <translation>Poistetaan arkisto...</translation>
    </message>
    <message>
        <location filename="../../borg/delete.py" line="13"/>
        <source>Archive deleted.</source>
        <translation>Arkisto poistettu.</translation>
    </message>
</context>
<context>
    <name>BorgDiffJob</name>
    <message>
        <location filename="../../borg/diff.py" line="9"/>
        <source>Requesting differences between archives...</source>
        <translation>Pyydetään eroavaisuuksia arkistojen välillä...</translation>
    </message>
    <message>
        <location filename="../../borg/diff.py" line="13"/>
        <source>Obtained differences between archives.</source>
        <translation>Saatiin arkistojen väliset eroavaisuudet.</translation>
    </message>
</context>
<context>
    <name>BorgExtractJob</name>
    <message>
        <location filename="../../borg/extract.py" line="8"/>
        <source>Downloading files from archive...</source>
        <translation>Ladataan tiedostoja arkistosta...</translation>
    </message>
    <message>
        <location filename="../../borg/extract.py" line="13"/>
        <source>Restored files from archive.</source>
        <translation>Palautettiin tiedostot arkistosta.</translation>
    </message>
</context>
<context>
    <name>BorgInfoArchiveJob</name>
    <message>
        <location filename="../../borg/info_archive.py" line="9"/>
        <source>Refreshing archive...</source>
        <translation>Päivitetään arkistoa...</translation>
    </message>
    <message>
        <location filename="../../borg/info_archive.py" line="14"/>
        <source>Refreshing archive done.</source>
        <translation>Arkiston päivittäminen onnistui.</translation>
    </message>
</context>
<context>
    <name>BorgInfoRepoJob</name>
    <message>
        <location filename="../../borg/info_repo.py" line="9"/>
        <source>Validating existing repo...</source>
        <translation>Vahvistetaan olemassa olevaa tietovarastoa...</translation>
    </message>
</context>
<context>
    <name>BorgInitJob</name>
    <message>
        <location filename="../../borg/init.py" line="8"/>
        <source>Setting up new repo...</source>
        <translation>Asetetaan uusi tietovarasto...</translation>
    </message>
</context>
<context>
    <name>BorgJob</name>
    <message>
        <location filename="../../borg/borg_job.py" line="66"/>
        <source>Files</source>
        <translation>Tiedostot</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="67"/>
        <source>Original</source>
        <translation>Alkuperäinen</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="68"/>
        <source>Deduplicated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="69"/>
        <source>Compressed</source>
        <translation>Pakattu</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="299"/>
        <source>Task started</source>
        <translation>Tehtävä käynnistetty</translation>
    </message>
</context>
<context>
    <name>BorgListArchiveJob</name>
    <message>
        <location filename="../../borg/list_archive.py" line="8"/>
        <source>Getting archive content...</source>
        <translation>Noudetaan arkiston sisältöä...</translation>
    </message>
    <message>
        <location filename="../../borg/list_archive.py" line="12"/>
        <source>Done getting archive content.</source>
        <translation>Saatiin arkiston sisältö.</translation>
    </message>
</context>
<context>
    <name>BorgListRepoJob</name>
    <message>
        <location filename="../../borg/list_repo.py" line="10"/>
        <source>Refreshing archives...</source>
        <translation>Päivitetään arkistoja...</translation>
    </message>
    <message>
        <location filename="../../borg/list_repo.py" line="15"/>
        <source>Refreshing archives done.</source>
        <translation>Arkistojen päivittäminen valmistui.</translation>
    </message>
</context>
<context>
    <name>BorgMountJob</name>
    <message>
        <location filename="../../borg/mount.py" line="9"/>
        <source>Mounting archive into folder...</source>
        <translation>Liitetään arkisto kansioon...</translation>
    </message>
</context>
<context>
    <name>BorgPruneJob</name>
    <message>
        <location filename="../../borg/prune.py" line="9"/>
        <source>Pruning old archives...</source>
        <translation>Karsitaan vanhoja arkistoja...</translation>
    </message>
    <message>
        <location filename="../../borg/prune.py" line="14"/>
        <source>Pruning done.</source>
        <translation>Karsiminen valmistui.</translation>
    </message>
</context>
<context>
    <name>BorgUmountJob</name>
    <message>
        <location filename="../../borg/umount.py" line="10"/>
        <source>Unmounting archive...</source>
        <translation>Irrotetaan arkiston liitosta...</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Valintaikkuna</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="25"/>
        <source>Archive:</source>
        <translation>Arkisto:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 from November 16, 2018</source>
        <translation>nyx2.local-2018-11-16T09:49:58 marraskuun 16., 2018</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="63"/>
        <source>Note: If you select a top-level folder and deselect its children, they will still be restored.</source>
        <translation>Huomio: Jos valitset ylätason hakemiston, sen alihakemistot palautetaan vaikka niitä ei olisi valittu.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="88"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="95"/>
        <source>Extract</source>
        <translation>Pura</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="35"/>
        <source>Add Backup Profile</source>
        <translation>Lisää varmuuskopioprofiili</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Backup profiles allow for granular backups from different sources to different destinations. You could e.g. back up essential documents to a remote repository via Wifi, while doing a full backup onto a local storage device.&lt;/p&gt;&lt;p&gt;Repositories and SSH keys are shared between profiles. Source folders, active destination repo, allowed networks, pruning, validation and scheduling are per-profile.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Varmuuskopioinnin profiilit mahdollistavat jaotellut varmuuskopiot eri lähteille eri kohteisiin. Voit esimerkiksi varmuuskopioida vain tärkeät dokumentit etäpalvelimelle Wifin kautta ja luoda täyden varmuuskopion paikalliselle tallennuslaitteelle.&lt;/p&gt;&lt;p&gt;Tietovarastot ja SSH-avaimet jaetaan profiilien kesken. Lähdekansiot, aktiiviset kohdetietovarastot sekä verkko-, karsimis-, tarkistus- ja ajastusasetukset ovat profiilikohtaisia.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="84"/>
        <source>Profile Name</source>
        <translation>Profiilin nimi</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="43"/>
        <source>Generate SSH Key</source>
        <translation>Luo SSH-avain</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="55"/>
        <source>Key Format:</source>
        <translation>Avaimen muoto:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="72"/>
        <source>Key Length:</source>
        <translation>Avaimen pituus:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="94"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 or 4096 for RSA, 384 or 521 for ECDSA. Fixed for Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;More&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 tai 4096 RSA:lle, 384 tai 521 ECDSA:lle. Kiinteä Ed25519:lle. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Lisää&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="107"/>
        <source>Output File:</source>
        <translation>Tulostetiedosto:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="119"/>
        <source>Don&apos;t change this if you want SSH to automatically find the key.</source>
        <translation>Älä muuta tätä, jos haluat SSH:n löytävän avaimen automaattisesti.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="128"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="141"/>
        <source>Generate and copy to Clipboard</source>
        <translation>Luo ja liitä leikepöydälle</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="25"/>
        <source>Select two archives</source>
        <translation>Valitse kaksi arkistoa</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="60"/>
        <source>Date</source>
        <translation>Päiväys</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="65"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="70"/>
        <source>Duration</source>
        <translation>Kesto</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="75"/>
        <source>Mount Point</source>
        <translation>Liitospiste</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="80"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="113"/>
        <source>Diff</source>
        <translation>Eroavaisuudet</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="25"/>
        <source>Difference between</source>
        <translation>Ero välillä</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 </source>
        <translation>nyx2.local-2018-11-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="45"/>
        <source>and</source>
        <translation>ja</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="58"/>
        <source>nyx2.local-2018-10-16T09:49:58 </source>
        <translation>nyx2.local-2018-10-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="101"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="23"/>
        <source>If set, sharing this file with others will disclose your borg passphrase. Use with caution!</source>
        <translation>Jos tämä on valittuna, viedyn tiedoston jakaminen muiden kanssa paljastaa Borgin tunnuslausesi. Käytä harkiten!</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="26"/>
        <source>Include borg passphrase in export</source>
        <translation>Sisällytä Borgin tunnuslause vientiin</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="25"/>
        <source>Borg passphrase:</source>
        <translation>Borgin tunnuslause:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="53"/>
        <source>Overwrite existing profile</source>
        <translation>Korvaa aikaisempi profiili</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="60"/>
        <source>Overwrite existing settings</source>
        <translation>Korvaa aikaisemmat asetukset</translation>
    </message>
</context>
<context>
    <name>EditProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="68"/>
        <source>Rename Profile</source>
        <translation>Nimeä profiili uudelleen</translation>
    </message>
</context>
<context>
    <name>ExistingRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="192"/>
        <source>Connect to existing Repository</source>
        <translation>Yhdistä olemassa olevaan tietovarastoon</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="210"/>
        <source>Show my password</source>
        <translation>Näytä salasana</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="207"/>
        <source>Hide my password</source>
        <translation>Piilota salasana</translation>
    </message>
</context>
<context>
    <name>ExportWindow</name>
    <message>
        <location filename="../../views/export_window.py" line="29"/>
        <source>Export Profile</source>
        <translation>Vie profiili</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="38"/>
        <source>The current profile_export has no password</source>
        <translation>Nykyisellä profiililla profile_export ei ole salasanaa</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="43"/>
        <source>Save profile_export</source>
        <translation>Tallenna profile_export</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="55"/>
        <source>Error while exporting</source>
        <translation>Vientivirhe</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="71"/>
        <source>The file {} could not be created. Please choose another location.</source>
        <translation>Tiedosta {} ei voitu luoda. Valitse toinen sijainti.</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export successful!</source>
        <translation>Profiilin vienti onnistui!</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export written to {}.</source>
        <translation>Profiili viety kohteeseen {}.</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="14"/>
        <source>Form</source>
        <translation>Lomake</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="44"/>
        <source>Archives</source>
        <translation>Arkistot</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="72"/>
        <source>Date</source>
        <translation>Päiväys</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="79"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="82"/>
        <source>Duration</source>
        <translation>Kesto</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="87"/>
        <source>Mount Point</source>
        <translation>Liitospiste</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="92"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="125"/>
        <source>Check</source>
        <translation>Tarkista</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="145"/>
        <source>Prune</source>
        <translation>Karsi</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="155"/>
        <source>Refresh</source>
        <translation>Päivitä</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="202"/>
        <source>Prune Options and Archive Naming</source>
        <translation>Karsimisvalinnat ja arkistojen nimeäminen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="229"/>
        <source>Keep</source>
        <translation>Säilytä</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="256"/>
        <source>Use -1 for unlimited.</source>
        <translation>-1 tarkoittaa rajoittamatonta.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="249"/>
        <source> hourly, </source>
        <translation>tunnittaista,</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="269"/>
        <source> daily, </source>
        <translation>päivittäistä,</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="283"/>
        <source> weekly, </source>
        <translation>viikottaista,</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="297"/>
        <source> monthly and</source>
        <translation>kuukausittaista ja</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="311"/>
        <source> annual archives</source>
        <translation>vuosittaista arkistoa</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="338"/>
        <source>No matter what, keep all archives of the last:</source>
        <translation>Säilytä aina arkistot, jotka on luotu tämän ajan sisällä:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="348"/>
        <source>24H, 1d, 52w, 12m, 1y</source>
        <translation>24t, 1pv, 52vk, 12kk, 1v</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="388"/>
        <source>Archive Name:</source>
        <translation>Arkiston nimi:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="431"/>
        <source>Available variables: hostname, profile_id, profile_slug, now, utc_now, user</source>
        <translation>Käytettävissä olevat muuttujat: hostname, profile_id, profile_slug, now, utc_now, user</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="398"/>
        <source>{hostname}-{profile_slug}-</source>
        <translation>{hostname}-{profile_slug}-</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="441"/>
        <source>Prune Prefix:</source>
        <translation>Karsittavien etuliite:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="71"/>
        <source>0.0</source>
        <translation>0.0</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="55"/>
        <source>Repository:</source>
        <translation>Tietovarasto:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="128"/>
        <source>Select Backup Destination</source>
        <translation>Valitse varmuuskopion kohde</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="136"/>
        <source>Unlink Repository (This doesn&apos;t delete any data. You can always add a repo again later.)</source>
        <translation>Poista tietovaraston linkitys (Tämä ei poista mitään tietoja. Voit lisätä tietovaraston uudelleen möhemmin.)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="164"/>
        <source>SSH Key:</source>
        <translation>SSH-avain:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="185"/>
        <source>Copy public SSH key to clipboard.</source>
        <translation>Kopioi julkinen SSH-avain leikepöydälle.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="222"/>
        <source>To securely access remote repositories. Keep default to use all your existing keys. Or create new key.</source>
        <translation>Turvallista yhdistämistä etätietovarastoihin varten. Pidä oletuksena käyttääksesi kaikkia olemassa olevia avaimiasi. Tai luo uusi avain. </translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="246"/>
        <source>Compression:</source>
        <translation>Pakkaus:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="347"/>
        <source>Encryption:</source>
        <translation>Salaus:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="387"/>
        <source>Original Size:</source>
        <translation>Alkuperäinen koko:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="401"/>
        <source>Deduplicated Size:</source>
        <translation>Deduplikoitu koko:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="408"/>
        <source>Compressed Size:</source>
        <translation>Pakattu koko:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="45"/>
        <source>Schedule</source>
        <translation>Ajastus</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="86"/>
        <source>Backup manually</source>
        <translation>Varmuuskopioi manuaalisesti</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="143"/>
        <source>Backup every </source>
        <translation>Varmuuskopioi</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="110"/>
        <source>Backup daily at</source>
        <translation>Varmuuskopioi päivittäin kello</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="279"/>
        <source>Validate repository data every</source>
        <translation>Vahvista tietovaraston tiedot</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="299"/>
        <source>weeks</source>
        <translation>viikon välein</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="225"/>
        <source>Prune old Archives after each backup</source>
        <translation>Karsi vanhat arkistot jokaisen varmuuskopioinnin jälkeen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="191"/>
        <source>Next Backup:</source>
        <translation>Seuraava varmuuskopiointi:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="345"/>
        <source>Networks</source>
        <translation>Verkot</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="357"/>
        <source>Allowed Networks:</source>
        <translation>Sallitut verkot:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="406"/>
        <source>Log</source>
        <translation>Loki</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="431"/>
        <source>Time</source>
        <translation>Aika</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="436"/>
        <source>Category</source>
        <translation>Luokka</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="441"/>
        <source>Subcommand</source>
        <translation>Alikomento</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="446"/>
        <source>Repository</source>
        <translation>Tietovarasto</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="451"/>
        <source>Returncode</source>
        <translation>Paluukoodi</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="468"/>
        <source>Shell Commands</source>
        <translation>Shell-komennot</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="477"/>
        <source>Run custom shell commands before and after each backup. The actual backup and post-backup command will only run, if the pre-backup command exits without error (return code 0).</source>
        <translation>Suorita omavalintaisia komentotulkkikomentoja ennen ja jälkeen varmuuskopiointien. Varsinainen varmuuskopion ja varmuuskopion jälkinen komento suoritetaan vain, jos ennen varmuuskopiointia suoritettava komento päättyy ilman virhettä (paluukoodi 0).</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="496"/>
        <source>Pre-backup command to run BEFORE backups</source>
        <translation>Ennen varmuuskopiointia suoritettava komento</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="506"/>
        <source>Post-backup command to run AFTER backups</source>
        <translation>Varmuuskopioinnin jälkeen suoritettava komento</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="519"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Available env variables: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Käytettävissä olevat ympäristömuuttujat: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="20"/>
        <source>Source Folders and Files to Back Up:</source>
        <translation>Varmuuskopioitavat kansiot ja tiedostot:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="94"/>
        <source>Add Folder</source>
        <translation>Lisää kansio</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="108"/>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="164"/>
        <source>Exclude If Present (exclude folders with these files):</source>
        <translation>Ohita hakemistot, jotka sisältävät tiedoston, jonka nimi sisältää:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="135"/>
        <source>Diff</source>
        <translation>Erot</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="183"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To mount archives, first install &amp;quot;FUSE for macOS&amp;quot; from &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;here&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Jotta voit liittää arkistot, asenna ensin &amp;quot;FUSE for macOS&amp;quot; &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;täältä&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="208"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pruning removes older archives. You can choose the number of hourly, daily, etc. archives to preserve. Usually you will keep more newer and fewer old archives. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Karsiminen poistaa vanhoja arkistoja. Voit valita, kuinka monta tunnittaista, päivittäistä jne. arkistoa säilytetään. Yleensä säilytetään useampia uudemmista arkistoista ja harvempia vanhemmista. Lue &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;lisää&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="64"/>
        <source>Vorta Version:</source>
        <translation>Vortan versio:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Report&lt;/span&gt;&lt;/a&gt; a Bug |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Ilmoita&lt;/span&gt;&lt;/a&gt; ongelmasta |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="91"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Log&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Loki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="127"/>
        <source>Borg Version:</source>
        <translation>Borgin versio:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="134"/>
        <source>1.1.8</source>
        <translation>1.1.8</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="141"/>
        <source>/usr/bin/borg</source>
        <translation>/usr/bin/borg</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="96"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remote or local backup repository. For simple and secure backup hosting, try &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Paikallisesti tai etänä sijaitseva tietovarasto. Kokeile&lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBasea&lt;/span&gt;&lt;/a&gt;, yksinkertaista ja turvallista varmuuskopiointipalvelinta.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="288"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Compression used for new data. Can be changed and doesn&apos;t affect deduplication. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pakkausmetodi uudelle datalle. Tätä voi vaihtaa eikä se vaikuta deduplikaatioon. Lue &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;lisää&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="154"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Exclude Patterns (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Kaavat tiedon poisjättämiselle (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;lisää&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="180"/>
        <source>E.g. **/.cache</source>
        <translation>Esim. **/.cache</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="193"/>
        <source>E.g. .nobackup</source>
        <translation>Esim. .nobackup</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="146"/>
        <source>Copy repo URL to clipboard</source>
        <translation>Kopioi tietovaraston URL leikepöydälle</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="364"/>
        <source>Don&apos;t run backup over metered networks</source>
        <translation>Älä varmuuskopioi laskutettavissa verkoissa</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="101"/>
        <source>Add File(s)</source>
        <translation>Lisää tiedosto(ja)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="115"/>
        <source>One folder or file per line</source>
        <translation>Yksi hakemisto tai tiedosto per rivi</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="118"/>
        <source>Paste Folders/Files</source>
        <translation>Liitä kansioita/tiedostoja</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="434"/>
        <source>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</source>
        <translation>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="69"/>
        <source>Path</source>
        <translation>Polku</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="74"/>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="84"/>
        <source>File Count</source>
        <translation>Tiedostomäärä</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="125"/>
        <source>Recalculate sizes</source>
        <translation>Laske koot uudelleen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="102"/>
        <source>Selected Archive</source>
        <translation>Valittu arkisto</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="542"/>
        <source>Add these arguments when creating a backup. See &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;the documentation&lt;/span&gt;&lt;/a&gt; for more information.</source>
        <translation>Käytä argumentteja, kun varmuuskopio luodaan. Katso lisätietoa &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;dokumentaatiosta&lt;/span&gt;&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="558"/>
        <source>Arguments to add. E.g. --dry-run</source>
        <translation>Lisättävät argumentit, esim. --dry-run</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="198"/>
        <source>-</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="252"/>
        <source>Run missed backups right after startup or wakeup</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImportWindow</name>
    <message>
        <location filename="../../views/import_window.py" line="25"/>
        <source>Import Profile</source>
        <translation>Tuo profiili</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="33"/>
        <source>The passphrase has been loaded from the export file</source>
        <translation>Tunnuslause on ladattu vientitiedostosta</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="40"/>
        <source>The passphrase has been loaded from your keyring</source>
        <translation>Tunnuslause on ladattu avainrenkaasta</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="50"/>
        <source>A profile with the name {} does not exist. Nothing to overwrite.</source>
        <translation>Profiilia nimellä {} ei ole ennestään joten sitä ei korvata.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="61"/>
        <source>Error while importing</source>
        <translation>Tuontivirhe</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="77"/>
        <source>Schema upgrade failure, file a bug report with the link in the Misc tab with the following error: 
 {0} 
 {1}</source>
        <translation>Skeeman päivitys epäonnistui, lähetä virheraportti Sekalaiset-välilehdellä olevasta linkistä. Liitä raporttiin seuraavat tiedot: 
 {0} 
 {1}</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="80"/>
        <source>Newer profile_export export files cannot be used on older versions.</source>
        <translation>Uudempia profile_export vientitiedostoja ei voida käyttää vanhemmilla versioilla.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="82"/>
        <source>Cannot read profile_export export file due to permission error.</source>
        <translation>profile_export-vientitiedostoa ei voitu lukea käyttöoikeusvirheen vuoksi.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="84"/>
        <source>Profile export file not found.</source>
        <translation>Profiilin vientitiedostoa ei löytynyt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../views/main_window.py" line="255"/>
        <source>Task cancelled</source>
        <translation>Tehtävä peruttu</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="51"/>
        <source>Current Profile:</source>
        <translation>Nykyinen profiili:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="84"/>
        <source>Rename Profile</source>
        <translation>Nimeä profiili uudelleen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="107"/>
        <source>Delete Profile</source>
        <translation>Poista profiili</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="148"/>
        <source>Repository</source>
        <translation>Tietovarasto</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="153"/>
        <source>Sources</source>
        <translation>Lähteet</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="158"/>
        <source>Schedule</source>
        <translation>Ajastus</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="163"/>
        <source>Archives</source>
        <translation>Arkistot</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="168"/>
        <source>Misc</source>
        <translation>Sekalaiset</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="190"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="36"/>
        <source>Start Backup</source>
        <translation>Käynnistä varmuuskopiointi</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="239"/>
        <source>Latest</source>
        <translation>Viimeisin</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="244"/>
        <source>Reset App</source>
        <translation>Nollaa asetukset</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="68"/>
        <source>Add Profile</source>
        <translation>Lisää profiili</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="163"/>
        <source>Are you sure you want to delete profile &apos;{}&apos;?</source>
        <translation>Haluatko varmasti poistaa profiilin &apos;{}&apos;?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="164"/>
        <source>Confirm deletion</source>
        <translation>Vahvista poistaminen</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="272"/>
        <source>Should Vorta continue to run in the background?</source>
        <translation>Tuleeko Vortan jatkaa käynnissä taustalla?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="277"/>
        <source>Quit</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="278"/>
        <source>Don&apos;t show this again</source>
        <translation>Älä näytä uudelleen</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="83"/>
        <source>Import from file...</source>
        <translation>Tuo tiedostosta...</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="174"/>
        <source>Can&apos;t delete the last profile.</source>
        <translation>Viimeistä profiilia ei voida poistaa.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="202"/>
        <source>Profile import successful!</source>
        <translation>Profiilin tuonti onnistui!</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="202"/>
        <source>Profile {} imported.</source>
        <translation>Profiili {} tuotu.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>Load profile</source>
        <translation>Lataa profiili</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>JSON (*.json);;All files (*)</source>
        <translation>JSON (*.json);;Kaikki tiedostot (*)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="97"/>
        <source>Export Profile</source>
        <translation>Vie profiili</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="220"/>
        <source>Failed to import profile</source>
        <translation>Profiilin tuonti epäonnistui</translation>
    </message>
</context>
<context>
    <name>RepoTab</name>
    <message>
        <location filename="../../views/repo_tab.py" line="26"/>
        <source>+ Initialize New Repository</source>
        <translation>+ Alusta uusi tietovarasto</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="27"/>
        <source>+ Add Existing Repository</source>
        <translation>+ Lisää olemassa oleva tietovarasto</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="48"/>
        <source>No Compression</source>
        <translation>Ei pakkausta</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="111"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>Valitse SSH-avain automaattisesti (oletus)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="112"/>
        <source>Create New Key</source>
        <translation>Luo uusi avain</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="149"/>
        <source>Public Key Copied to Clipboard</source>
        <translation>Julkinen avain kopioitu leikepöydälle</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="150"/>
        <source>The selected public SSH key was copied to the clipboard. Use it to set up remote repo permissions.</source>
        <translation>Valittu julkinen SSH-avain kopioitiin leikepöydälle. Käytä sitä tietovaraston käyttöoikeuksien asettamiseen.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="155"/>
        <source>Couldn&apos;t find public key.</source>
        <translation>Julkista avainta ei löydy.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="157"/>
        <source>Select a public key from the dropdown first.</source>
        <translation>Valitse ensin julkinen avain pudotusvalikosta.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="213"/>
        <source>Repository was Unlinked</source>
        <translation>Linkitys tietovarastoon poistettiin</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="214"/>
        <source>You can always connect it again later.</source>
        <translation>Voit yhdistää siihen aina uudelleen.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="38"/>
        <source>LZ4 (modern, default)</source>
        <translation>LZ4 (nykyaikainen, oletus)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="39"/>
        <source>Zstandard Level 3 (modern)</source>
        <translation>Zstandard Level 3 (nykyaikainen)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="40"/>
        <source>Zstandard Level 8 (modern)</source>
        <translation>Zstandard Level 8 (nykyaikainen)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="46"/>
        <source>ZLIB Level 6 (auto, legacy)</source>
        <translation>ZLIB Level 6 (auto, vanha)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="47"/>
        <source>LZMA Level 6 (auto, legacy)</source>
        <translation>LZMA Level 6 (auto, vanha)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="228"/>
        <source>Select a repository from the dropdown first.</source>
        <translation>Valitse ensin tietovarasto pudotusvalikosta.</translation>
    </message>
</context>
<context>
    <name>SSHAddWindow</name>
    <message>
        <location filename="../../views/ssh_dialog.py" line="35"/>
        <source>ED25519 (Recommended)</source>
        <translation>ED25519 (suositeltu)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="36"/>
        <source>RSA (Legacy)</source>
        <translation>RSA (vanha)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="37"/>
        <source>ECDSA</source>
        <translation>ECDSA</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="46"/>
        <source>High (Recommended)</source>
        <translation>Korkea (suositeltu)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="47"/>
        <source>Medium</source>
        <translation>Keskitaso</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="60"/>
        <source>Key file already exists. Not overwriting.</source>
        <translation>Avaintiedosto on jo olemassa. Ei korvata.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="72"/>
        <source>New key was copied to clipboard and written to %s.</source>
        <translation>Uusi avain kopioitiin leikepöydälle ja kirjoitettiin sijaintiin %s.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="74"/>
        <source>Error during key generation.</source>
        <translation>Virhe avainta luotaessa.</translation>
    </message>
</context>
<context>
    <name>ScheduleTab</name>
    <message>
        <location filename="../../views/schedule_tab.py" line="43"/>
        <source>Minutes</source>
        <translation>Minuutit</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="44"/>
        <source>Hours</source>
        <translation>Tunnit</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="45"/>
        <source>Days</source>
        <translation>Päivät</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="46"/>
        <source>Weeks</source>
        <translation>Viikot</translation>
    </message>
</context>
<context>
    <name>SourceTab</name>
    <message>
        <location filename="../../views/source_tab.py" line="173"/>
        <source>Choose directory to back up</source>
        <translation>Valitse varmuuskopioitava kansio</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="173"/>
        <source>Choose file(s) to back up</source>
        <translation>Valitse varmuuskopioitava(t) tiedosto(t)</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="130"/>
        <source>Folder</source>
        <translation>Kansio</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="134"/>
        <source>File</source>
        <translation>Tiedosto</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="102"/>
        <source>Calculating...</source>
        <translation>Lasketaan...</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="164"/>
        <source>You don&apos;t have read access to {dir}.</source>
        <translation>Ei lukuoikeutta kohteeseen {dir}.</translation>
    </message>
</context>
<context>
    <name>TrayMenu</name>
    <message>
        <location filename="../../tray_menu.py" line="42"/>
        <source>Vorta for Borg Backup</source>
        <translation>Vorta Borg-varmuuskopiointi</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="53"/>
        <source>Cancel Backup</source>
        <translation>Peru varmuuskopiointi</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="56"/>
        <source>Next Task: %s</source>
        <translation>Seuraava tehtävä: %s</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="65"/>
        <source>Backup Now</source>
        <translation>Varmuuskopioi nyt</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="70"/>
        <source>Quit</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="52"/>
        <source>Task in progress</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VortaApp</name>
    <message>
        <location filename="../../application.py" line="129"/>
        <source>Vorta Backup</source>
        <translation>Vorta-varmuuskopiointi</translation>
    </message>
    <message>
        <location filename="../../application.py" line="191"/>
        <source>No Borg Binary Found</source>
        <translation>Borg-binääriä ei löytynyt</translation>
    </message>
    <message>
        <location filename="../../application.py" line="192"/>
        <source>Vorta was unable to locate a usable Borg Backup binary.</source>
        <translation>Vorta ei kyennyt paikallistamaan Borg-varmuuskopioinnin binääritiedostoa.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="229"/>
        <source>Repository In Use</source>
        <translation>Tietovarasto käytössä</translation>
    </message>
    <message>
        <location filename="../../application.py" line="231"/>
        <source>Abort</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <location filename="../../application.py" line="232"/>
        <source>Continue</source>
        <translation>Jatka</translation>
    </message>
    <message>
        <location filename="../../application.py" line="234"/>
        <source>The repository at {repo_url} might be in use elsewhere.</source>
        <translation>Tietovarasto osoitteessa {repo_url} saattaa olla käytössä jossain muualla.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="235"/>
        <source>Only break the lock if you are certain no other Borg process on any machine is accessing the repository. Abort or break the lock?</source>
        <translation>Pura lukitus vain, jos olet varma että mikään muu Borg-prosessi ei käytä tietovarastoa. Perutaanko vai puretaanko lukitus?</translation>
    </message>
    <message>
        <location filename="../../application.py" line="243"/>
        <source>You do not have permission to access the repository at {repo_url}. Gain access and try again.</source>
        <translation>Sinulla ei ole käyttöoikeutta tietovaraston {repo_url} käyttämiseksi. Hanki käyttöoikeudet ja yritä uudelleen.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="246"/>
        <source>No Repository Permissions</source>
        <translation>Ei tietovaraston käyttöoikeuksia</translation>
    </message>
    <message>
        <location filename="../../application.py" line="210"/>
        <source>Vorta needs Full Disk Access for complete Backups</source>
        <translation>Vorta tarvitsee koko levyn käytön täydellisiin varmuuskopioihin</translation>
    </message>
    <message>
        <location filename="../../application.py" line="211"/>
        <source>Without this, some files won&apos;t be accessible and you may end up with an incomplete backup. Please set &lt;b&gt;Full Disk Access&lt;/b&gt; permission for Vorta in &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;System Preferences &gt; Security &amp; Privacy&lt;/a&gt;.</source>
        <translation>Ilman tätä jotkin tiedostot eivät ole käytettävissä ja varmuuskopio saattaa jäädä vajaaksi. Anna Vortalle lupa &lt;b&gt;koko levyn käyttöön&lt;/b&gt; avaamalla &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;Järjestelmäasetukset &gt; Suojaus ja yksityisyys&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="283"/>
        <source>Profile import successful!</source>
        <translation>Profiilin tuonti onnistui!</translation>
    </message>
    <message>
        <location filename="../../application.py" line="283"/>
        <source>Profile {} imported.</source>
        <translation>Profiili {} tuotu.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Failed to import profile</source>
        <translation>Profiilin tuonti epäonnistui</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Failed to import a profile from {}:</source>
        <translation>Profiilin tuonti epäonnistui kohteesta {}:</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Consider removing or repairing this file to get rid of this message.</source>
        <translation>Harkitse tämän tiedoston poistamista tai korjaamista välttääksesi tämän viestin.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="295"/>
        <source>Repo Check Failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="296"/>
        <source>Repository data check for repo %s failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="297"/>
        <source>Repair or recreate the repository soon to avoid missing data.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VortaScheduler</name>
    <message>
        <location filename="../../scheduler.py" line="143"/>
        <source>None scheduled</source>
        <translation>Ei mitään aikataulutettu</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="190"/>
        <source>Vorta Backup</source>
        <translation>Vorta-varmuuskopiointi</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="162"/>
        <source>Starting background backup for %s.</source>
        <translation>Aloitetaan profiilin %s varmuuskopiointia taustalla.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="184"/>
        <source>Backup successful for %s.</source>
        <translation>Profiilin %s varmuuskopiointi onnistui.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="190"/>
        <source>Error during backup creation.</source>
        <translation>Virhe varmuuskopiota luotaessa.</translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="../../__main__.py" line="22"/>
        <source>Fatal Error</source>
        <translation>Kohtalokas virhe</translation>
    </message>
    <message>
        <location filename="../../__main__.py" line="23"/>
        <source>Uncaught exception, please file a report with this text at
https://github.com/borgbase/vorta/issues/new
</source>
        <translation>Tapahtui tuntematon virhe. Raportoithan virheen tekstin osoitteessa
https://github.com/borgbase/vorta/issues/new
</translation>
    </message>
</context>
<context>
    <name>messages</name>
    <message>
        <location filename="../../borg/version.py" line="20"/>
        <source>Borg binary was not found.</source>
        <translation>Borg-binääritiedostoa ei löytynyt.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="140"/>
        <source>Add a backup repository first.</source>
        <translation>Lisää ensin tietovarasto varmuuskopiointia varten.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="82"/>
        <source>Add some folders to back up first.</source>
        <translation>Lisää ensin joitain kansioita varmuuskopioon.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="98"/>
        <source>Current Wifi is not allowed.</source>
        <translation>Nykyinen wifi-verkko ei ole sallittu.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="115"/>
        <source>Repo folder not mounted or moved.</source>
        <translation>Tietovaraston kansiota ei ole liitetty tai se on siirretty.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="111"/>
        <source>Pre-backup command returned non-zero exit code.</source>
        <translation>Varmuuskopioinnin esikomento palautti poistumiskoodiksi muun kuin nollan.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="165"/>
        <source>Starting backup...</source>
        <translation>Käynnistetään varmuuskopiointi...</translation>
    </message>
    <message>
        <location filename="../../borg/umount.py" line="27"/>
        <source>No active Borg mounts found.</source>
        <translation>Aktiivisia Borg-liitoksia ei löytynyt.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="144"/>
        <source>Your Borg version is too old. &gt;=1.1.0 is required.</source>
        <translation>Käyttämäsi Borg-versio on liian vanha. &gt;=1.1.0 vaaditaan.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="119"/>
        <source>Your current Borg version does not support ZStd compression.</source>
        <translation>Käytössäsi oleva Borg-versio ei tue ZStd-pakkausta.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="103"/>
        <source>Not running backup over metered connection.</source>
        <translation>Varmuuskopiointia ei suoriteta laskutettavalla yhteydellä.</translation>
    </message>
    <message>
        <location filename="../../borg/info_repo.py" line="43"/>
        <source>Please unlock your password manager.</source>
        <translation>Avaa salasanahallintasovelluksesi lukitus.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="171"/>
        <source>Your repo passphrase was stored in a password manager which is no longer available.
Try unlinking and re-adding your repo.</source>
        <translation>Tietovaraston salasana oli tallennettuna salasanahallintaan, joka ei ole enää saatavilla.
Poista tietovaraston linkitys ja lisää se uudelleen.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="155"/>
        <source>Please unlock your system password manager or disable it under Misc</source>
        <translation>Avaa järjestelmän salasananhallinnan lukitus tai ota se pois käytöstä sekalaisista asetuksista</translation>
    </message>
</context>
<context>
    <name>utils</name>
    <message>
        <location filename="../../utils.py" line="412"/>
        <source>Passwords must be identical and greater than 8 characters long.</source>
        <translation>Salasanojen tulee olla identtiset ja pidempiä kuin 8 merkkiä.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="414"/>
        <source>Passwords must be identical.</source>
        <translation>Salasanojen tulee olla identtiset.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="416"/>
        <source>Passwords must be greater than 8 characters long.</source>
        <translation>Salasanojen tulee olla pidempiä kuin 8 merkkiä.</translation>
    </message>
</context>
</TS>